==> yearmaps-0.0.9.tar.gz: yearmaps-0.0.9/yearmaps/interface/task.py <==
import hashlib
from copy import deepcopy
from pathlib import Path
from typing import Dict
from datetime import date

import click

from yearmaps.constant import Configs
from yearmaps.utils.util import dict_hash, str_hash


class Task:
    def __init__(self,
                 context: click.Context,
                 command: click.Command,
                 global_options: Dict,
                 options: Dict):
        self.command = command
        self.command_options = options
        self.context = deepcopy(context)
        self.global_config: Configs = self.context.obj
        for key, value in global_options.items():
            setattr(self.global_config, key, value)
        self.global_config.output = str(Path(
            self.global_config.output) / f"{self.task_hash()}.{self.global_config.file_type}")

    def run(self, force=False):
        if self.should_run() or force:
            self.context.invoke(self.command, **self.command_options)

    def should_run(self) -> bool:
        if self.context.obj.mode == 'year':
            if date.today().year == self.global_config.year:
                return True
        return False

    def task_hash(self) -> str:
        command_options_hash = dict_hash(self.command_options)
        global_options_hash = self.global_config.hash()
        return str_hash(command_options_hash, global_options_hash, self.command.name)

    def cache_path(self) -> Path:
        return Path(self.global_config.output)

    def task_name(self) -> str:
        return f"{self.command.name} {self.command_options} {self.global_config}"

    def ensure_cache(self, quiet=False):
        if not quiet:
            click.echo(f"Ensuring cache for {self.global_config} {self.command_options}")
        if not self.cache_path().exists():
            self.run(force=True)

==> yearmaps-0.0.14.tar.gz: yearmaps-0.0.14/yearmaps/interface/task.py <==
import hashlib
from copy import deepcopy
from pathlib import Path
from typing import Dict
from datetime import date

import click

from yearmaps.constant import Configs
from yearmaps.utils.util import dict_hash, str_hash


class Task:
    def __init__(self,
                 context: click.Context,
                 command: click.Command,
                 global_options: Dict,
                 options: Dict):
        self.command = command
        self.command_options = options
        self.context = deepcopy(context)
        self.global_config: Configs = self.context.obj
        for key, value in global_options.items():
            setattr(self.global_config, key, value)
        self.global_config.output = str(Path(
            self.global_config.output) / f"{self.task_hash()}.{self.global_config.file_type}")

    def run(self, force=False):
        if self.should_run() or force:
            self.context.invoke(self.command, **self.command_options)

    def should_run(self) -> bool:
        if self.context.obj.mode == 'year':
            if date.today().year == self.global_config.year:
                return True
        return False

    def task_hash(self) -> str:
        command_options_hash = dict_hash(self.command_options)
        global_options_hash = self.global_config.hash()
        return str_hash(command_options_hash, global_options_hash, self.command.name)

    def cache_path(self) -> Path:
        return Path(self.global_config.output)

    def task_name(self) -> str:
        return f"{self.command.name} {self.command_options} {self.global_config} \n{self.task_hash()}"

    def ensure_cache(self, quiet=False):
        if not quiet:
            click.echo(f"Ensuring cache for {self.global_config} {self.command_options}")
        if not self.cache_path().exists():
            self.run(force=True)
